@@ -1,6 +1,5 @@
 import json
 import uuid
-from distutils.version import StrictVersion
 from typing import Any, Callable, Optional
 
 from aiohttp import web
@@ -8,9 +7,17 @@ from aiohttp import web
 from . import AbstractStorage, Session
 
 try:
-    import aioredis
+    from redis import VERSION as REDIS_VERSION, asyncio as aioredis
 except ImportError:  # pragma: no cover
-    aioredis = None  # type: ignore[assignment]
+    try:
+        import aioredis  # type: ignore[import, no-redef]  # noqa: I900
+    except ImportError:
+        aioredis = None  # type: ignore[assignment]
+    else:
+        import warnings
+        warnings.warn("aioredis library is deprecated, please replace with redis.",
+                      DeprecationWarning)
+        REDIS_VERSION = (4, 3)
 
 
 class RedisStorage(AbstractStorage):
@@ -18,7 +25,7 @@ class RedisStorage(AbstractStorage):
 
     def __init__(
         self,
-        redis_pool: "aioredis.Redis",
+        redis_pool: "aioredis.Redis[bytes]",
         *,
         cookie_name: str = "AIOHTTP_SESSION",
         domain: Optional[str] = None,
@@ -43,13 +50,13 @@ class RedisStorage(AbstractStorage):
             decoder=decoder,
         )
         if aioredis is None:
-            raise RuntimeError("Please install aioredis")
+            raise RuntimeError("Please install redis")
         # May have installed aioredis separately (without aiohttp-session[aioredis]).
-        if StrictVersion(aioredis.__version__).version < (2, 0):
-            raise RuntimeError("aioredis<2.0 is not supported")
+        if REDIS_VERSION < (4, 3):
+            raise RuntimeError("redis<4.3 is not supported")
         self._key_factory = key_factory
         if not isinstance(redis_pool, aioredis.Redis):
-            raise TypeError(f"Expected aioredis.Redis got {type(redis_pool)}")
+            raise TypeError(f"Expected redis.asyncio.Redis got {type(redis_pool)}")
         self._redis = redis_pool
 
     async def load_session(self, request: web.Request) -> Session:
@@ -58,12 +65,12 @@ class RedisStorage(AbstractStorage):
             return Session(None, data=None, new=True, max_age=self.max_age)
         else:
             key = str(cookie)
-            data = await self._redis.get(self.cookie_name + "_" + key)
-            if data is None:
+            data_bytes = await self._redis.get(self.cookie_name + "_" + key)
+            if data_bytes is None:
                 return Session(None, data=None, new=True, max_age=self.max_age)
-            data = data.decode("utf-8")
+            data_str = data_bytes.decode("utf-8")
             try:
-                data = self._decoder(data)
+                data = self._decoder(data_str)
             except ValueError:
                 data = None
             return Session(key, data=data, new=False, max_age=self.max_age)
@@ -82,9 +89,9 @@ class RedisStorage(AbstractStorage):
                 key = str(key)
                 self.save_cookie(response, key, max_age=session.max_age)
 
-        data = self._encoder(self._get_session_data(session))
+        data_str = self._encoder(self._get_session_data(session))
         await self._redis.set(
             self.cookie_name + "_" + key,
-            data,
-            ex=session.max_age,  # type: ignore[arg-type]
+            data_str,
+            ex=session.max_age,
         )
