@@ -32,7 +32,9 @@ def make_cookie(client: TestClient, fernet: Fernet, data: Dict[str, Any]) -> Non
     client.session.cookie_jar.update_cookies({"AIOHTTP_SESSION": encrypted_data})
 
 
-def create_app(handler: Handler, key: Union[str, bytes, bytearray, Fernet]) -> web.Application:
+def create_app(
+    handler: Handler, key: Union[str, bytes, bytearray, Fernet]
+) -> web.Application:
     middleware = session_middleware(EncryptedCookieStorage(key))
     app = web.Application(middlewares=[middleware])
     app.router.add_route("GET", "/", handler)
@@ -103,7 +105,7 @@ async def test_load_existing_session(
 
 
 async def test_load_existing_session_with_fernet(
-  aiohttp_client: AiohttpClient, fernet: Fernet
+    aiohttp_client: AiohttpClient, fernet: Fernet
 ) -> None:
     async def handler(request: web.Request) -> web.StreamResponse:
         session = await get_session(request)
