@@ -1,14 +1,16 @@
+from __future__ import annotations
+
 import asyncio
 import json
 import time
 import uuid
 from typing import Any, Callable, Dict, MutableMapping, Optional, cast
 
-import aioredis
 import pytest
 from aiohttp import web
 from aiohttp.test_utils import TestClient
 from pytest_mock import MockFixture
+from redis import asyncio as aioredis
 
 from aiohttp_session import Handler, Session, get_session, session_middleware
 from aiohttp_session.redis_storage import RedisStorage
@@ -18,7 +20,7 @@ from .typedefs import AiohttpClient
 
 def create_app(
     handler: Handler,
-    redis: aioredis.Redis,
+    redis: aioredis.Redis[bytes],
     max_age: Optional[int] = None,
     key_factory: Callable[[], str] = lambda: uuid.uuid4().hex,
 ) -> web.Application:
@@ -31,7 +33,7 @@ def create_app(
 
 
 async def make_cookie(
-    client: TestClient, redis: aioredis.Redis, data: Dict[Any, Any]
+    client: TestClient, redis: aioredis.Redis[bytes], data: Dict[Any, Any]
 ) -> None:
     session_data = {"session": data, "created": int(time.time())}
     value = json.dumps(session_data)
@@ -40,23 +42,21 @@ async def make_cookie(
     client.session.cookie_jar.update_cookies({"AIOHTTP_SESSION": key})
 
 
-async def make_cookie_with_bad_value(client: TestClient, redis: aioredis.Redis) -> None:
+async def make_cookie_with_bad_value(client: TestClient, redis: aioredis.Redis[bytes]) -> None:
     key = uuid.uuid4().hex
     await redis.set("AIOHTTP_SESSION_" + key, "")
     client.session.cookie_jar.update_cookies({"AIOHTTP_SESSION": key})
 
 
-async def load_cookie(client: TestClient, redis: aioredis.Redis) -> Any:
+async def load_cookie(client: TestClient, redis: aioredis.Redis[bytes]) -> Any:
     cookies = client.session.cookie_jar.filter_cookies(client.make_url("/"))
     key = cookies["AIOHTTP_SESSION"]
-    encoded = await redis.get("AIOHTTP_SESSION_" + key.value)
-    s = encoded.decode("utf-8")
-    value = json.loads(s)
-    return value
+    value_bytes = await redis.get("AIOHTTP_SESSION_" + key.value)
+    return None if value_bytes is None else json.loads(value_bytes)
 
 
 async def test_create_new_session(
-    aiohttp_client: AiohttpClient, redis: aioredis.Redis
+    aiohttp_client: AiohttpClient, redis: aioredis.Redis[bytes]
 ) -> None:
     async def handler(request: web.Request) -> web.StreamResponse:
         session = await get_session(request)
@@ -72,7 +72,7 @@ async def test_create_new_session(
 
 
 async def test_load_existing_session(
-    aiohttp_client: AiohttpClient, redis: aioredis.Redis
+    aiohttp_client: AiohttpClient, redis: aioredis.Redis[bytes]
 ) -> None:
     async def handler(request: web.Request) -> web.StreamResponse:
         session = await get_session(request)
@@ -89,7 +89,7 @@ async def test_load_existing_session(
 
 
 async def test_load_bad_session(
-    aiohttp_client: AiohttpClient, redis: aioredis.Redis
+    aiohttp_client: AiohttpClient, redis: aioredis.Redis[bytes]
 ) -> None:
     async def handler(request: web.Request) -> web.StreamResponse:
         session = await get_session(request)
@@ -106,7 +106,7 @@ async def test_load_bad_session(
 
 
 async def test_change_session(
-    aiohttp_client: AiohttpClient, redis: aioredis.Redis
+    aiohttp_client: AiohttpClient, redis: aioredis.Redis[bytes]
 ) -> None:
     async def handler(request: web.Request) -> web.StreamResponse:
         session = await get_session(request)
@@ -133,7 +133,7 @@ async def test_change_session(
 
 
 async def test_clear_cookie_on_session_invalidation(
-    aiohttp_client: AiohttpClient, redis: aioredis.Redis
+    aiohttp_client: AiohttpClient, redis: aioredis.Redis[bytes]
 ) -> None:
     async def handler(request: web.Request) -> web.StreamResponse:
         session = await get_session(request)
@@ -154,7 +154,7 @@ async def test_clear_cookie_on_session_invalidation(
 
 
 async def test_create_cookie_in_handler(
-    aiohttp_client: AiohttpClient, redis: aioredis.Redis
+    aiohttp_client: AiohttpClient, redis: aioredis.Redis[bytes]
 ) -> None:
     async def handler(request: web.Request) -> web.StreamResponse:
         session = await get_session(request)
@@ -181,7 +181,7 @@ async def test_create_cookie_in_handler(
 
 
 async def test_set_ttl_on_session_saving(
-    aiohttp_client: AiohttpClient, redis: aioredis.Redis
+    aiohttp_client: AiohttpClient, redis: aioredis.Redis[bytes]
 ) -> None:
     async def handler(request: web.Request) -> web.StreamResponse:
         session = await get_session(request)
@@ -201,7 +201,7 @@ async def test_set_ttl_on_session_saving(
 
 
 async def test_set_ttl_manually_set(
-    aiohttp_client: AiohttpClient, redis: aioredis.Redis
+    aiohttp_client: AiohttpClient, redis: aioredis.Redis[bytes]
 ) -> None:
     async def handler(request: web.Request) -> web.StreamResponse:
         session = await get_session(request)
@@ -222,7 +222,7 @@ async def test_set_ttl_manually_set(
 
 
 async def test_create_new_session_if_key_doesnt_exists_in_redis(
-    aiohttp_client: AiohttpClient, redis: aioredis.Redis
+    aiohttp_client: AiohttpClient, redis: aioredis.Redis[bytes]
 ) -> None:
     async def handler(request: web.Request) -> web.StreamResponse:
         session = await get_session(request)
@@ -236,7 +236,7 @@ async def test_create_new_session_if_key_doesnt_exists_in_redis(
 
 
 async def test_create_storage_with_custom_key_factory(
-    aiohttp_client: AiohttpClient, redis: aioredis.Redis
+    aiohttp_client: AiohttpClient, redis: aioredis.Redis[bytes]
 ) -> None:
     async def handler(request: web.Request) -> web.StreamResponse:
         session = await get_session(request)
@@ -259,7 +259,7 @@ async def test_create_storage_with_custom_key_factory(
 
 
 async def test_redis_session_fixation(
-    aiohttp_client: AiohttpClient, redis: aioredis.Redis
+    aiohttp_client: AiohttpClient, redis: aioredis.Redis[bytes]
 ) -> None:
     async def login(request: web.Request) -> web.StreamResponse:
         session = await get_session(request)
@@ -288,7 +288,7 @@ async def test_redis_from_create_pool(redis_url: str) -> None:
     async def handler(request: web.Request) -> web.StreamResponse:
         pass
 
-    redis = aioredis.from_url(redis_url)  # type: ignore[no-untyped-call]
+    redis = aioredis.from_url(redis_url)
     create_app(handler=handler, redis=redis)
     await redis.close()
 
@@ -314,17 +314,13 @@ async def test_old_aioredis_version(mocker: MockFixture) -> None:
     async def handler(request: web.Request) -> web.StreamResponse:
         pass
 
-    class Dummy:
-        def __init__(self, *args: object, **kwargs: object) -> None:
-            self.version = (0, 3)
-
-    mocker.patch("aiohttp_session.redis_storage.StrictVersion", Dummy)
+    mocker.patch("aiohttp_session.redis_storage.REDIS_VERSION", (0, 3, "dev0"))
     with pytest.raises(RuntimeError):
         create_app(handler=handler, redis=None)  # type: ignore[arg-type]
 
 
 async def test_load_session_dont_load_expired_session(
-    aiohttp_client: AiohttpClient, redis: aioredis.Redis
+    aiohttp_client: AiohttpClient, redis: aioredis.Redis[bytes]
 ) -> None:
     async def handler(request: web.Request) -> web.StreamResponse:
         session = await get_session(request)
